/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *  TOKENS.HPP -- token class declarations              V1.0  *
 *                                                           *
 *  Operations:                                              *
 *  - Constructs class objects with public member string     *
 *    objects and input stream pointers.                     *
 *  Assumptions:                                             *
 *  - tokens.hpp header file will be included with any C++   *
 *    source file wishing to use string services.            *
 *                                                           *
 *  History:                                                 *
 *  - V1.0 - 14 Jun 92                                       *
 *                                                           *
 *  Language:       Borland C++                              *
 *  System:         Gateway 386/25, MS-DOS 5.0               *
 *  Application:    CSE 687                                  *
 *  Author:         Jim Fawcett, CST 2-127, (315)443-4454    *
 *                                                           *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#ifndef TOKENS_HPP
#define TOKENS_HPP
#include <fstream.h>
#include "strings.hpp"

enum bool { no, yes };
enum code { C_code, Cpp_code };

class token {

  protected:

    fstream ifstrm;                   // pointer to input stream
    char    *delims;                  // token delimiters
    string  prev_tok;                 // holds token putbacks
    long    position;                 // pointer to current token
    long    prev_position;            // pointer to last token
    long    top_position;             // pointer to file top
    int     lines;                    // number of newlines

  public:

    string  str;                      // public data member

    token(void);                      // open void token
    token(char *filename);            // attach stream to filename
    ~token(void);                     // destroy token
    int  open(char *filename)         // attach stream to filename
	     { ifstrm.open(filename,ios::in); return ifstrm.good(); }
    void close(void)                  // close stream
	     { ifstrm.close(); }
    int  lines_read(void)             // input lines read
	     { return lines; }
    friend int  next(token &tok);     // get another token from file
    friend int  prev(token &tok);     // get previous token from file
    friend int  done(token &tok);     // test for end of file
    friend void rewind(token &tok);   // rewind file
    friend int  get_tok(token &tok);  // get a token from ifstrm
    friend void putback(token &tok);  // push token back
    friend int collect_parens(token &tok);
				      // return parentheses string
    friend int collect_comments(token &tok, code type);
				      // return comment string
    friend int collect_quotes(token &tok, char qch);
				      // return quoted string
};

#endif
